pub struct RequestedAddressFamily(/* private fields */);Expand description
This attribute is used in Allocate and Refresh requests to specify the address type requested by the client.
See https://datatracker.ietf.org/doc/html/rfc8656#name-requested-address-family for details.
Implementations
Sourceimpl RequestedAddressFamily
impl RequestedAddressFamily
Sourcepub fn new(fam: AddressFamily) -> RequestedAddressFamily
pub fn new(fam: AddressFamily) -> RequestedAddressFamily
Makes a new RequestedAddressFamily instance.
Sourcepub fn address_family(&self) -> AddressFamily
pub fn address_family(&self) -> AddressFamily
Returns the requested address family.