pub struct Software { /* private fields */ }Expand description
SOFTWARE attribute.
See RFC 5389 – 15.10. SOFTWARE about this attribute.
Implementations
Sourceimpl Software
impl Software
Sourcepub fn new(description: String) -> Result<Software, Error>
pub fn new(description: String) -> Result<Software, Error>
Makes a new Software instance.
Errors
The length of description must be less than 128 characters.
If it is too long, this will return an ErrorKind::InvalidInput error.
Sourcepub const fn new_static(description: &'static str) -> Software
pub const fn new_static(description: &'static str) -> Software
Makes a new Software instance from a static string.
This function is const, so you can create this in a const context.
Panics
The length of description must be less than 128 characters.
Panics if the string is longer.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the description of this instance.