#[non_exhaustive]pub enum Error {
Show 21 variants
MaxRetriesExceeded,
PeerAddressFamilyMismatch,
Closed,
SameChannelDifferentPeer,
SamePeerDifferentChannel,
LifetimeZero,
DupeFiveTuple,
NoSuchUser,
UnexpectedClass,
RelayAlreadyAllocatedForFiveTuple,
AttributeNotFound,
IntegrityMismatch,
NoDontFragmentSupport,
RequestWithReservationTokenAndEvenPort,
RequestWithReservationTokenAndReqAddressFamily,
NoAllocationFound,
UnsupportedRelayProto,
NoPermission,
NoSuchChannelBind,
Encode(ErrorKind),
Transport(Error),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
MaxRetriesExceeded
Failed to allocate new relay connection, since maximum retires count exceeded.
PeerAddressFamilyMismatch
{eer address is part of a different address family than that of the relayed transport address of the allocation.
Closed
Error when trying to perform action after closing server.
SameChannelDifferentPeer
Channel binding request failed, since channel number is currently bound to a different transport address.
SamePeerDifferentChannel
Channel binding request failed, since the transport address is currently bound to a different channel number.
LifetimeZero
Cannot create allocation with zero lifetime.
DupeFiveTuple
Cannot create allocation for the same five-tuple.
NoSuchUser
Authentication error.
UnexpectedClass
Unsupported request class.
RelayAlreadyAllocatedForFiveTuple
Allocation request failed, since allocation already exists for the
provided FiveTuple.
AttributeNotFound
STUN message doesn’t have a required attribute.
IntegrityMismatch
STUN message contains wrong MessageIntegrity.
NoDontFragmentSupport
DONT-FRAGMENT attribute is not supported.
RequestWithReservationTokenAndEvenPort
Allocation request cannot have both RESERVATION-TOKEN and EVEN-PORT.
RequestWithReservationTokenAndReqAddressFamily
Allocation request cannot contain both RESERVATION-TOKEN and REQUESTED-ADDRESS-FAMILY.
NoAllocationFound
No allocation for the provided FiveTuple.
UnsupportedRelayProto
The specified protocol is not supported.
NoPermission
Failed to handle Send Indication, since there is no permission for the provided address.
NoSuchChannelBind
Failed to handle channel data, since there is no binding for the provided channel.
Encode(ErrorKind)
Failed to encode message.
Transport(Error)
Failed to send message.