Server

Struct Server 

pub struct Server { /* private fields */ }
Instance of a STUN/TURN server.

Implementations

Source

impl Server

pub fn new<A>(config: Config<A>) -> Self
where A: AuthHandler + Send + Sync + 'static,

Creates a new Server according to the provided Config, and spawns its internal loop.

pub async fn delete_allocations_by_username( &self, username: String, ) -> Result<(), Error>

Deletes all existing allocations with the provided username.

Errors

With an Error::Closed if the Server was closed already.

pub async fn get_allocations_info( &self, five_tuples: Option<Vec<FiveTuple>>, ) -> Result<HashMap<FiveTuple, Info>, Error>

Returns Infos for the provided FiveTuples.

If five_tuples is:

  • None: It returns information about the all allocations.
  • Some and not empty: It returns information about the allocations associated with the specified FiveTuples.
  • Some, but empty: It returns an empty HashMap.
Errors

With an Error::Closed if the Server was closed already.

pub fn healthz(&self) -> bool

Checks healthiness of this Server based on whether all the initialized long-running transport loops are still running.